@@ -95,6 +95,9 @@ class ParameterMixin(BaseModel):
             warnings.warn(f"Key {parameter_name} is not in the model. Adding.")
         self.add_and_update_parameter(parameter_name, parameter_value)
 
+    def scale_parameter(self, parameter_name: str, factor: float) -> None:
+        self.parameters[parameter_name]  *= factor
+
     def update_parameters(self, parameters: Dict[str, float]) -> None:
         """Update multiple existing model parameters.
 
@@ -184,6 +187,19 @@ class ParameterMixin(BaseModel):
             parameter_value=function(*parameter_values),
         )
 
+    def update_derived_parameter(
+        self, parameter_name: str, function: Callable | None, parameters: List[str] | None
+    ) -> None:
+        old = self.derived_parameters[parameter_name]
+        if function is None:
+            function = old["function"]
+        if parameters is None:
+            parameters = old["parameters"]
+
+        self.derived_parameters[parameter_name]["function"] = function
+        self.derived_parameters[parameter_name]["parameters"] = parameters
+        self._update_derived_parameters()
+
     def remove_derived_parameter(self, parameter_name: str) -> None:
         """Remove a derived parameter from the model."""
         old_parameter = self.derived_parameters.pop(parameter_name)
