@@ -16,4 +16,4 @@ from .linearlabelmodel import LinearLabelModel
 from .model import Model
 
 BASE_MODEL_TYPE = TypeVar("BASE_MODEL_TYPE", bound=_AbstractStoichiometricModel)
-RATE_MODEL_TYPE = TypeVar("RATE_MODEL_TYPE", bound=Model)
+RATE_MODEL_TYPE = TypeVar("RATE_MODEL_TYPE", bound=_AbstractRateModel)
