@@ -50,7 +50,9 @@ class _AbstractRateModel(RateMixin, AlgebraicMixin, _AbstractStoichiometricModel
         self.remove_parameters(self.check_unused_parameters())
 
     def _collect_used_compounds(self) -> Set[str]:
-        return set((i for i in self.compounds if len(self.stoichiometries_by_compounds[i]) > 0))
+        return set(
+            (i for i in self.compounds if len(self.stoichiometries_by_compounds[i]) > 0)
+        )
 
     def check_unused_compounds(self) -> Set[str]:
         used_compounds = self._collect_used_compounds()
@@ -109,7 +111,9 @@ class _AbstractRateModel(RateMixin, AlgebraicMixin, _AbstractStoichiometricModel
         """Calculate the fluxes at time point(s) t."""
         if isinstance(t, (int, float)):
             t = [t]  # type: ignore
-        return pd.DataFrame(data=self.get_fluxes_dict(y=y, t=t), index=t, columns=self.get_rate_names())
+        return pd.DataFrame(
+            data=self.get_fluxes_dict(y=y, t=t), index=t, columns=self.get_rate_names()
+        )
 
     def get_right_hand_side(
         self,
