@@ -108,7 +108,9 @@ class LinearLabelModel(_AbstractStoichiometricModel):
             self.remove_compound(compound=compound)
             warnings.warn(f"Overwriting compound {compound}")
 
-        label_names = self._generate_isotope_labels(base_name=compound, num_labels=num_labels)
+        label_names = self._generate_isotope_labels(
+            base_name=compound, num_labels=num_labels
+        )
         self.isotopomers[compound] = label_names
         self._check_and_insert_ids([compound], context="add_compound")
 
@@ -163,7 +165,9 @@ class LinearLabelModel(_AbstractStoichiometricModel):
             substrate=substrate,
         )
         self.base_rates.setdefault(base_name, set()).add(rate_name)
-        self.meta_info.setdefault("rates", {}).setdefault(rate_name, RateMeta(**meta_info))
+        self.meta_info.setdefault("rates", {}).setdefault(
+            rate_name, RateMeta(**meta_info)
+        )
 
     def remove_rate(self, rate_name: str) -> None:
         del self.rates[rate_name]
@@ -172,7 +176,9 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         return list(self.rates.keys())
 
     @staticmethod
-    def _unpack_stoichiometries(*, stoichiometries: Dict[str, int]) -> Tuple[Dict[str, int], Dict[str, int]]:
+    def _unpack_stoichiometries(
+        *, stoichiometries: Dict[str, int]
+    ) -> Tuple[Dict[str, int], Dict[str, int]]:
         """Split stoichiometries into substrates and products."""
         substrates = {}
         products = {}
@@ -200,13 +206,17 @@ class LinearLabelModel(_AbstractStoichiometricModel):
     ) -> None:
         # Add label outfluxes
         if (diff := len(substrates) - len(products)) > 0:
-            warnings.warn(f"Added {diff} external label outflux(es) for reaction {rate_name}")
+            warnings.warn(
+                f"Added {diff} external label outflux(es) for reaction {rate_name}"
+            )
             for _ in range(diff):
                 products.append("EXT")
 
         # Label influxes
         if (diff := len(products) - len(substrates)) > 0:
-            warnings.warn(f"Added {diff} external label influx(es) for reaction {rate_name}")
+            warnings.warn(
+                f"Added {diff} external label influx(es) for reaction {rate_name}"
+            )
             for _ in range(diff):
                 substrates.append("EXT")
 
@@ -215,10 +225,14 @@ class LinearLabelModel(_AbstractStoichiometricModel):
             raise ValueError(f"Labelmap 'missing' {abs(diff)} label(s)")
 
     @staticmethod
-    def _map_substrates_to_labelmap(*, substrates: List[str], labelmap: List[int]) -> List[str]:
+    def _map_substrates_to_labelmap(
+        *, substrates: List[str], labelmap: List[int]
+    ) -> List[str]:
         return [substrates[i] for i in labelmap]
 
-    def add_reaction(self, rate_name: str, stoichiometry: Dict[str, int], labelmap: List[int]) -> None:
+    def add_reaction(
+        self, rate_name: str, stoichiometry: Dict[str, int], labelmap: List[int]
+    ) -> None:
         """Add a reaction to the model.
 
         Examples
@@ -230,7 +244,9 @@ class LinearLabelModel(_AbstractStoichiometricModel):
             self.remove_reaction(rate_name=rate_name)
 
         substrates, products = self._unpack_stoichiometries(stoichiometries=stoichiometry)
-        self.add_reaction_from_substrates_and_products(rate_name, substrates, products, labelmap)
+        self.add_reaction_from_substrates_and_products(
+            rate_name, substrates, products, labelmap
+        )
 
     def add_reaction_from_substrates_and_products(
         self,
@@ -257,7 +273,9 @@ class LinearLabelModel(_AbstractStoichiometricModel):
             if substrate == product:
                 warnings.warn(f"Ignoring rate {rate_name}__{i}, as substrate == product")
                 continue
-            self.add_stoichiometry(rate_name=f"{rate_name}__{i}", stoichiometry={substrate: -1, product: 1})
+            self.add_stoichiometry(
+                rate_name=f"{rate_name}__{i}", stoichiometry={substrate: -1, product: 1}
+            )
             self.add_rate(
                 rate_name=f"{rate_name}__{i}",
                 base_name=rate_name,
@@ -307,7 +325,9 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         fcd["EXT"] = external_label
         fluxes = {}
         for name, rate in self.rates.items():
-            fluxes[name] = relative_label_flux(fcd[rate["substrate"]], v_ss[rate["base_name"]])
+            fluxes[name] = relative_label_flux(
+                fcd[rate["substrate"]], v_ss[rate["base_name"]]
+            )
         return fluxes
 
     def get_fluxes_dict(
@@ -376,7 +396,9 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         fcd = dict(zip(self.compounds, y_labels))
         dxdt: Dict[str, float] = {i: 0.0 for i in self.compounds}
 
-        fluxes = self._get_fluxes(fcd=fcd, v_ss=self._v_ss, external_label=self._external_label)
+        fluxes = self._get_fluxes(
+            fcd=fcd, v_ss=self._v_ss, external_label=self._external_label
+        )
         for compound, isotopomers in self.isotopomers.items():
             for isotomoper in isotopomers:
                 for rate, stoich in self.stoichiometries_by_compounds[isotomoper].items():
