@@ -1,6 +1,7 @@
 """The main class for modeling. Provides model construction and inspection tools."""
 
 from __future__ import annotations
+from dataclasses import dataclass
 
 __all__ = [
     "Model",
@@ -32,6 +33,12 @@ if TYPE_CHECKING:
     from . import LabelModel, LinearLabelModel
 
 
+@dataclass
+class DerivedStoichiometry:
+    function: Callable[..., float]
+    args: list[str]
+
+
 class Model(_AbstractRateModel, BaseModel):
     """The main class for modeling. Provides model construction and inspection tools."""
 
@@ -52,8 +59,9 @@ class Model(_AbstractRateModel, BaseModel):
         StoichiometricMixin.__init__(self, rate_stoichiometries=rate_stoichiometries)
         RateMixin.__init__(self, rates=rates, functions=functions)
         self.meta_info["model"].sbo = "SBO:0000062"  # continuous framework
+        self.derived_stoichiometries: Dict[str, DerivedStoichiometry] = {}
 
-    def __enter__(self) -> Model:
+    def __enter__(self) -> "Model":
         """Enter the context manager.
 
         Returns
@@ -63,7 +71,7 @@ class Model(_AbstractRateModel, BaseModel):
         self._copy = self.copy()
         return self.copy()
 
-    def copy(self) -> Model:
+    def copy(self) -> "Model":
         """Create a deepcopy of the model.
 
         Returns
@@ -87,7 +95,7 @@ class Model(_AbstractRateModel, BaseModel):
         )
 
     def _element_difference(
-        self, other: Model, attribute: str
+        self, other: "Model", attribute: str
     ) -> Optional[Union[List[str], Dict[str, List[str]]]]:
         self_collection = getattr(self, attribute)
         other_collection = getattr(other, attribute)
@@ -99,7 +107,7 @@ class Model(_AbstractRateModel, BaseModel):
         return {k: other_collection[k] for k in difference}
 
     def _element_intersection(
-        self, other: Model, attribute: str
+        self, other: "Model", attribute: str
     ) -> Optional[Union[List[str], Dict[str, List[str]]]]:
         self_collection = getattr(self, attribute)
         other_collection = getattr(other, attribute)
@@ -112,33 +120,26 @@ class Model(_AbstractRateModel, BaseModel):
             return intersection
         return {k: other_collection[k] for k in intersection}
 
-    def __add__(self, other: Model) -> Model:
-        m: Model = self.copy()
-        m.add(**{"compounds": self._element_difference(other, "compounds")})  # type: ignore
-        m.add(**{"parameters": self._element_difference(other, "parameters")})  # type: ignore
-        m.update(**{"parameters": self._element_intersection(other, "parameters")})  # type: ignore
+    def __add__(self, other: "Model") -> "Model":
+        return self.copy().__iadd__(other)
 
-        for name, module in other.algebraic_modules.items():
-            if name in self.algebraic_modules:
-                m.update_algebraic_module(name, **dict(module))
-            else:
-                m.add_algebraic_module(name, **dict(module))
-
-        for attribute in [
-            "rates",
-            "stoichiometries",
-            "functions",
-        ]:
-            m.add(**{attribute: self._element_difference(other, attribute)})  # type: ignore
-            m.update(**{attribute: self._element_intersection(other, attribute)})  # type: ignore
-        return m
-
-    def __iadd__(self, other: Model) -> Model:
+    def __iadd__(self, other: "Model") -> "Model":
         self.add(**{"compounds": self._element_difference(other, "compounds")})  # type: ignore
-        self.add(**{"parameters": self._element_difference(other, "parameters")})  # type: ignore
-        self.update(**{"parameters": self._element_intersection(other, "parameters")})  # type: ignore
 
-        for name, module in other.algebraic_modules.items():
+        for k, v in other.parameters.items():
+            if k not in other.derived_parameters:
+                self.add_and_update_parameter(k, v)
+
+        for k, dpar in other.derived_parameters.items():
+            if k in self.derived_parameters:
+                self.update_derived_parameter(k, dpar["function"], dpar["parameters"])
+            else:
+                self.add_derived_parameter(
+                    k, function=dpar["function"], parameters=dpar["parameters"]
+                )
+
+        for name in other._algebraic_module_order:
+            module = other.algebraic_modules[name]
             if name in self.algebraic_modules:
                 self.update_algebraic_module(name, **dict(module))
             else:
@@ -153,7 +154,7 @@ class Model(_AbstractRateModel, BaseModel):
             self.update(**{attribute: self._element_intersection(other, attribute)})  # type: ignore
         return self
 
-    def __sub__(self, other: Model) -> Model:
+    def __sub__(self, other: "Model") -> "Model":
         m: Model = self.copy()
         for attribute in [
             "compounds",
@@ -166,17 +167,8 @@ class Model(_AbstractRateModel, BaseModel):
             m.remove(**{attribute: self._element_intersection(other, attribute)})  # type: ignore
         return m
 
-    def __isub__(self, other: Model) -> Model:
-        for attribute in [
-            "compounds",
-            "parameters",
-            "algebraic_modules",
-            "rates",
-            "stoichiometries",
-            "functions",
-        ]:
-            self.remove(**{attribute: self._element_intersection(other, attribute)})  # type: ignore
-        return self
+    def __isub__(self, other: "Model") -> Model:
+        return self.copy().__sub__(other)
 
     def add(
         self,
@@ -245,6 +237,18 @@ class Model(_AbstractRateModel, BaseModel):
     # Reactions
     ##########################################################################
 
+    # def add_derived_stoichiometry(
+    #     self, name: str, function: Callable, args: list[str]
+    # ) -> None:
+    #     raise NotImplementedError
+
+    # def _update_derived_stoichiometries(self) -> None:
+    #     for name, stoichiometry in self.derived_stoichiometries.items():
+    #         factor = stoichiometry.function(
+    #             *(self.parameters[i] for i in stoichiometry.args)
+    #         )
+    #         self.update_stoichiometry(name, factor)
+
     def add_reaction(
         self,
         rate_name: str,
@@ -391,12 +395,59 @@ class Model(_AbstractRateModel, BaseModel):
     def update_reaction_from_args(
         self,
         rate_name: str,
+        function: Callable[..., float] | None = None,
         stoichiometry: Dict[str, float] | None = None,
         args: List[str] | None = None,
         reversible: bool | None = None,
         check_consistency: bool = True,
     ) -> None:
-        raise NotImplementedError
+        if stoichiometry is None:
+            stoichiometry = self.stoichiometries[rate_name]
+        else:
+            self.update_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
+
+        if function is None:
+            function = self.rates[rate_name].function
+
+        if args is not None:
+            modifiers = []
+            parameters = []
+            dynamic_variables = []
+            for i in args:
+                if i in self.parameters:
+                    parameters.append(i)
+                elif i not in stoichiometry:
+                    modifiers.append(i)
+                    dynamic_variables.append(i)
+                else:
+                    dynamic_variables.append(i)
+            substrates = [k for k, v in stoichiometry.items() if v < 0]
+            products = [k for k, v in stoichiometry.items() if v > 0]
+            if reversible is None:
+                if any(i in dynamic_variables for i in products):
+                    reversible = True
+                else:
+                    reversible = False
+        else:
+            substrates = self.rates[rate_name].substrates
+            products = self.rates[rate_name].products
+            modifiers = self.rates[rate_name].modifiers
+            parameters = self.rates[rate_name].parameters
+            dynamic_variables = self.rates[rate_name].dynamic_variables
+            args = self.rates[rate_name].args
+
+        self.update_rate(
+            rate_name=rate_name,
+            function=function,
+            substrates=substrates,
+            products=products,
+            modifiers=modifiers,
+            parameters=parameters,
+            reversible=reversible,
+            dynamic_variables=dynamic_variables,
+            args=args,
+            check_consistency=check_consistency,
+        )
 
     def add_reaction_from_ratelaw(
         self,
